@@ -20,7 +20,7 @@ def run_mq_command(mq_command):
         script_file.write(f"""
         #!/bin/bash
         . /opt/mqm/bin/setmqenv -s
-        sudo -E bash -c '{mq_command}'
+        {mq_command}
         """)
         script_file_path = script_file.name
     os.chmod(script_file_path, 0o755)
@@ -90,8 +90,11 @@ def get_queue_permissions(args):
 
     for queue_name in queue_names:
         command = f'/opt/mqm/bin/dspmqaut -m {queue_manager} -t q -n "{queue_name}" -p {user}'
-        permissions_output = run_command(command)
-        print(f"Permissions for queue '{queue_name}':\n{permissions_output}\n")
+        try:
+            permissions_output = run_command(command)
+            print(f"Permissions for queue '{queue_name}':\n{permissions_output}\n")
+        except RuntimeError as e:
+            print(f"Error fetching permissions for queue '{queue_name}': {e}")
 
 def main():
     parser = argparse.ArgumentParser(description="IBM MQ Management CLI")
